==> apache-cassandra-4.0.19-src.tar.gz: apache-cassandra-4.0.19-src/src/java/org/apache/cassandra/gms/FailureDetectorMBean.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.cassandra.gms;

import java.net.UnknownHostException;
import java.util.Map;

import javax.management.openmbean.OpenDataException;
import javax.management.openmbean.TabularData;

public interface FailureDetectorMBean
{
    public void dumpInterArrivalTimes();

    public void setPhiConvictThreshold(double phi);

    public double getPhiConvictThreshold();

    @Deprecated public String getAllEndpointStates();
    public String getAllEndpointStatesWithPort();

    public String getEndpointState(String address) throws UnknownHostException;

    @Deprecated public Map<String, String> getSimpleStates();
    public Map<String, String> getSimpleStatesWithPort();

    public int getDownEndpointCount();

    public int getUpEndpointCount();

    @Deprecated public TabularData getPhiValues() throws OpenDataException;
    public TabularData getPhiValuesWithPort() throws OpenDataException;
}

==> apache-cassandra-4.1.10-src.tar.gz: apache-cassandra-4.1.10-src/src/java/org/apache/cassandra/gms/FailureDetectorMBean.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.cassandra.gms;

import java.net.UnknownHostException;
import java.util.Map;

import javax.management.openmbean.OpenDataException;
import javax.management.openmbean.TabularData;

public interface FailureDetectorMBean
{
    public void dumpInterArrivalTimes();

    public void setPhiConvictThreshold(double phi);

    public double getPhiConvictThreshold();

    @Deprecated public String getAllEndpointStates();
    @Deprecated public String getAllEndpointStatesWithResolveIp();
    public String getAllEndpointStatesWithPort();
    public String getAllEndpointStatesWithPortAndResolveIp();

    public String getEndpointState(String address) throws UnknownHostException;

    @Deprecated public Map<String, String> getSimpleStates();
    public Map<String, String> getSimpleStatesWithPort();

    public int getDownEndpointCount();

    public int getUpEndpointCount();

    @Deprecated public TabularData getPhiValues() throws OpenDataException;
    public TabularData getPhiValuesWithPort() throws OpenDataException;
}
